we are going to design an AI Agent for our business, the scenarios as belw:
- we have a application called "my client service"
- it has some advanced function, which involve many step user interation across many pages
- so we would like to have an Chat window + AI agent + a set of rules of my client service function + my client service mcp
so in order to build the Chat Window + AI Agent which can understand business to call tools like mcp. how should I do?
could you provide steps, tech stack to me.